=======================
collective.jsonmigrator
=======================

JSON based migrations for Plone

``collective.jsonmigrator`` is a ready tool for you to migrate from old Plone
sites (2.0, 2.1, 2.5) to new Plone 4.0 (or higher). Its based extensivly
`collective.transmogrifier`_ and custom blueprints avaliable.

What makes it different from other migration tools is that is `fully
documented`_ and proven to work on lots of migration projects.  (ATTENTION!
docs are outdated and come from the older collective.blueprint.jsonmigrator
project. Contributions are welcome.)

Real beauty of it lays in ability to easily customize it and extend to support
all your custom content types that you are using.

(Note that collective.jsonmigrator was previously named
`collective.blueprint.jsonmigrator`_).

.. _`collective.transmogrifier`: http://pypi.python.org/pypi/collective.transmogrifier
.. _`fully documented`: http://readthedocs.org/docs/collectivejsonmigrator/en/latest/
.. _`collective.blueprint.jsonmigrator`: https://github.com/collective/collective.jsonmigrator/commit/747af7d0be1bf16f12822ef4841f40f5bb23a6b6
